@@ -9,13 +9,14 @@ use std::{
 
 use crate::{http::StatusCode, IntoResponse, Response};
 
-macro_rules! define_error {
+macro_rules! define_http_error {
     ($($(#[$docs:meta])* ($name:ident, $status:ident);)*) => {
         $(
         $(#[$docs])*
+        #[allow(non_snake_case)]
         #[inline]
-        pub fn $name(err: impl StdError + Send + Sync + 'static) -> Self {
-            Self::new(StatusCode::$status).with_reason(err)
+        pub fn $name(err: impl StdError + Send + Sync + 'static) -> Error {
+            Error::new(StatusCode::$status).with_reason(err)
         }
         )*
     };
@@ -28,6 +29,12 @@ pub struct Error {
     reason: anyhow::Error,
 }
 
+impl<T: Into<Error> + Send> IntoResponse for T {
+    fn into_response(self) -> Response {
+        Into::<Error>::into(self).as_response()
+    }
+}
+
 impl From<Infallible> for Error {
     fn from(_: Infallible) -> Self {
         unreachable!()
@@ -103,89 +110,89 @@ impl Error {
             .status(self.status)
             .body(self.reason().to_string())
     }
-
-    define_error!(
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::BAD_REQUEST`].
-        (bad_request, BAD_REQUEST);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::UNAUTHORIZED`].
-        (unauthorized, UNAUTHORIZED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::PAYMENT_REQUIRED`].
-        (payment_required, PAYMENT_REQUIRED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::FORBIDDEN`].
-        (forbidden, FORBIDDEN);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::NOT_FOUND`].
-        (not_found, NOT_FOUND);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::METHOD_NOT_ALLOWED`].
-        (method_not_allowed, METHOD_NOT_ALLOWED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::NOT_ACCEPTABLE`].
-        (not_acceptable, NOT_ACCEPTABLE);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::PROXY_AUTHENTICATION_REQUIRED`].
-        (proxy_authentication_required, PROXY_AUTHENTICATION_REQUIRED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::REQUEST_TIMEOUT`].
-        (request_timeout, REQUEST_TIMEOUT);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::CONFLICT`].
-        (conflict, CONFLICT);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::GONE`].
-        (gone, GONE);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::LENGTH_REQUIRED`].
-        (length_required, LENGTH_REQUIRED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::PAYLOAD_TOO_LARGE`].
-        (payload_too_large, PAYLOAD_TOO_LARGE);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::URI_TOO_LONG`].
-        (uri_too_long, URI_TOO_LONG);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::UNSUPPORTED_MEDIA_TYPE`].
-        (unsupported_media_type, UNSUPPORTED_MEDIA_TYPE);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::RANGE_NOT_SATISFIABLE`].
-        (range_not_satisfiable, RANGE_NOT_SATISFIABLE);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::IM_A_TEAPOT`].
-        (im_a_teapot, IM_A_TEAPOT);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::MISDIRECTED_REQUEST`].
-        (misdirected_request, MISDIRECTED_REQUEST);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::UNPROCESSABLE_ENTITY`].
-        (unprocessable_entity, UNPROCESSABLE_ENTITY);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::LOCKED`].
-        (locked, LOCKED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::FAILED_DEPENDENCY`].
-        (failed_dependency, FAILED_DEPENDENCY);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::UPGRADE_REQUIRED`].
-        (upgrade_required, UPGRADE_REQUIRED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::PRECONDITION_FAILED`].
-        (precondition_failed, PRECONDITION_FAILED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::PRECONDITION_REQUIRED`].
-        (precondition_required, PRECONDITION_REQUIRED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::TOO_MANY_REQUESTS`].
-        (too_many_requests, TOO_MANY_REQUESTS);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::REQUEST_HEADER_FIELDS_TOO_LARGE`].
-        (request_header_fields_too_large, REQUEST_HEADER_FIELDS_TOO_LARGE);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::UNAVAILABLE_FOR_LEGAL_REASONS`].
-        (unavailable_for_legal_reasons, UNAVAILABLE_FOR_LEGAL_REASONS);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::EXPECTATION_FAILED`].
-        (expectation_failed, EXPECTATION_FAILED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::INTERNAL_SERVER_ERROR`].
-        (internal_server_error, INTERNAL_SERVER_ERROR);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::NOT_IMPLEMENTED`].
-        (not_implemented, NOT_IMPLEMENTED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::BAD_GATEWAY`].
-        (bad_gateway, BAD_GATEWAY);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::SERVICE_UNAVAILABLE`].
-        (service_unavailable, SERVICE_UNAVAILABLE);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::GATEWAY_TIMEOUT`].
-        (gateway_timeout, GATEWAY_TIMEOUT);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::HTTP_VERSION_NOT_SUPPORTED`].
-        (http_version_not_supported, HTTP_VERSION_NOT_SUPPORTED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::VARIANT_ALSO_NEGOTIATES`].
-        (variant_also_negotiates, VARIANT_ALSO_NEGOTIATES);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::INSUFFICIENT_STORAGE`].
-        (insufficient_storage, INSUFFICIENT_STORAGE);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::LOOP_DETECTED`].
-        (loop_detected, LOOP_DETECTED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::NOT_EXTENDED`].
-        (not_extended, NOT_EXTENDED);
-        /// Wraps any error into [`Error`] and the status code is [`StatusCode::NETWORK_AUTHENTICATION_REQUIRED`].
-        (network_authentication_required, NETWORK_AUTHENTICATION_REQUIRED);
-    );
 }
 
+define_http_error!(
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::BAD_REQUEST`].
+    (BadRequest, BAD_REQUEST);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::UNAUTHORIZED`].
+    (Unauthorized, UNAUTHORIZED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::PAYMENT_REQUIRED`].
+    (PaymentRequired, PAYMENT_REQUIRED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::FORBIDDEN`].
+    (Forbidden, FORBIDDEN);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::NOT_FOUND`].
+    (NotFound, NOT_FOUND);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::METHOD_NOT_ALLOWED`].
+    (MethodNotAllowed, METHOD_NOT_ALLOWED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::NOT_ACCEPTABLE`].
+    (NotAcceptable, NOT_ACCEPTABLE);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::PROXY_AUTHENTICATION_REQUIRED`].
+    (ProxyAuthenticationRequired, PROXY_AUTHENTICATION_REQUIRED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::REQUEST_TIMEOUT`].
+    (RequestTimeout, REQUEST_TIMEOUT);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::CONFLICT`].
+    (Conflict, CONFLICT);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::GONE`].
+    (Gone, GONE);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::LENGTH_REQUIRED`].
+    (LengthRequired, LENGTH_REQUIRED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::PAYLOAD_TOO_LARGE`].
+    (PayloadTooLarge, PAYLOAD_TOO_LARGE);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::URI_TOO_LONG`].
+    (UriTooLong, URI_TOO_LONG);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::UNSUPPORTED_MEDIA_TYPE`].
+    (UnsupportedMediaType, UNSUPPORTED_MEDIA_TYPE);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::RANGE_NOT_SATISFIABLE`].
+    (RangeNotSatisfiable, RANGE_NOT_SATISFIABLE);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::IM_A_TEAPOT`].
+    (ImATeapot, IM_A_TEAPOT);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::MISDIRECTED_REQUEST`].
+    (MisdirectedRequest, MISDIRECTED_REQUEST);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::UNPROCESSABLE_ENTITY`].
+    (UnprocessableEntity, UNPROCESSABLE_ENTITY);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::LOCKED`].
+    (Locked, LOCKED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::FAILED_DEPENDENCY`].
+    (FailedDependency, FAILED_DEPENDENCY);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::UPGRADE_REQUIRED`].
+    (UpgradeRequired, UPGRADE_REQUIRED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::PRECONDITION_FAILED`].
+    (PreconditionFailed, PRECONDITION_FAILED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::PRECONDITION_REQUIRED`].
+    (PreconditionRequired, PRECONDITION_REQUIRED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::TOO_MANY_REQUESTS`].
+    (TooManyRequests, TOO_MANY_REQUESTS);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::REQUEST_HEADER_FIELDS_TOO_LARGE`].
+    (RequestHeaderFieldsTooLarge, REQUEST_HEADER_FIELDS_TOO_LARGE);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::UNAVAILABLE_FOR_LEGAL_REASONS`].
+    (UnavailableForLegalReasons, UNAVAILABLE_FOR_LEGAL_REASONS);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::EXPECTATION_FAILED`].
+    (ExpectationFailed, EXPECTATION_FAILED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::INTERNAL_SERVER_ERROR`].
+    (InternalServerError, INTERNAL_SERVER_ERROR);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::NOT_IMPLEMENTED`].
+    (NotImplemented, NOT_IMPLEMENTED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::BAD_GATEWAY`].
+    (BadGateway, BAD_GATEWAY);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::SERVICE_UNAVAILABLE`].
+    (ServiceUnavailable, SERVICE_UNAVAILABLE);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::GATEWAY_TIMEOUT`].
+    (GatewayTimeout, GATEWAY_TIMEOUT);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::HTTP_VERSION_NOT_SUPPORTED`].
+    (HttpVersionNotSupported, HTTP_VERSION_NOT_SUPPORTED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::VARIANT_ALSO_NEGOTIATES`].
+    (VariantAlsoNegotiates, VARIANT_ALSO_NEGOTIATES);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::INSUFFICIENT_STORAGE`].
+    (InsufficientStorage, INSUFFICIENT_STORAGE);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::LOOP_DETECTED`].
+    (LoopDetected, LOOP_DETECTED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::NOT_EXTENDED`].
+    (NotExtended, NOT_EXTENDED);
+    /// Wraps any error into [`Error`] and the status code is [`StatusCode::NETWORK_AUTHENTICATION_REQUIRED`].
+    (NetworkAuthenticationRequired, NETWORK_AUTHENTICATION_REQUIRED);
+);
+
 /// A specialized Result type for Poem.
 pub type Result<T, E = Error> = ::std::result::Result<T, E>;
 
@@ -248,9 +255,9 @@ pub enum ReadBodyError {
 impl From<ReadBodyError> for Error {
     fn from(err: ReadBodyError) -> Self {
         match err {
-            ReadBodyError::BodyHasBeenTaken => Error::internal_server_error(err),
-            ReadBodyError::Utf8(err) => Error::bad_request(err),
-            ReadBodyError::Io(err) => Error::bad_request(err),
+            ReadBodyError::BodyHasBeenTaken => InternalServerError(err),
+            ReadBodyError::Utf8(err) => BadRequest(err),
+            ReadBodyError::Io(err) => BadRequest(err),
         }
     }
 }
@@ -276,7 +283,7 @@ pub enum ParseCookieError {
 #[cfg(feature = "cookie")]
 impl From<ParseCookieError> for Error {
     fn from(err: ParseCookieError) -> Self {
-        Error::bad_request(err)
+        BadRequest(err)
     }
 }
 
@@ -287,7 +294,7 @@ pub struct GetDataError(pub &'static str);
 
 impl From<GetDataError> for Error {
     fn from(err: GetDataError) -> Self {
-        Error::internal_server_error(err)
+        InternalServerError(err)
     }
 }
 
@@ -313,7 +320,7 @@ pub enum ParseFormError {
 
 impl From<ParseFormError> for Error {
     fn from(err: ParseFormError) -> Self {
-        Error::bad_request(err)
+        BadRequest(err)
     }
 }
 
@@ -331,7 +338,7 @@ pub enum ParseJsonError {
 
 impl From<ParseJsonError> for Error {
     fn from(err: ParseJsonError) -> Self {
-        Error::bad_request(err)
+        BadRequest(err)
     }
 }
 
@@ -342,7 +349,7 @@ pub struct ParseQueryError(#[from] pub serde_urlencoded::de::Error);
 
 impl From<ParseQueryError> for Error {
     fn from(err: ParseQueryError) -> Self {
-        Error::bad_request(err)
+        BadRequest(err)
     }
 }
 
@@ -371,13 +378,7 @@ pub enum ParseMultipartError {
 #[cfg(feature = "multipart")]
 impl From<ParseMultipartError> for Error {
     fn from(err: ParseMultipartError) -> Self {
-        Error::bad_request(err)
-    }
-}
-
-impl<T: Into<Error> + Send> IntoResponse for T {
-    fn into_response(self) -> Response {
-        Into::<Error>::into(self).as_response()
+        BadRequest(err)
     }
 }
 
@@ -395,7 +396,7 @@ pub enum ParseTypedHeaderError {
 
 impl From<ParseTypedHeaderError> for Error {
     fn from(err: ParseTypedHeaderError) -> Self {
-        Error::bad_request(err)
+        BadRequest(err)
     }
 }
 
@@ -417,8 +418,8 @@ pub enum WebSocketError {
 impl From<WebSocketError> for Error {
     fn from(err: WebSocketError) -> Self {
         match &err {
-            WebSocketError::InvalidProtocol => Error::bad_request(err),
-            WebSocketError::NoUpgrade => Error::internal_server_error(err),
+            WebSocketError::InvalidProtocol => BadRequest(err),
+            WebSocketError::NoUpgrade => InternalServerError(err),
         }
     }
 }
